@@ -1,22 +1,8 @@
 /***********************************************************************
-* Copyright 2003-2004  Max Howell <max.howell@methylblue.com>
-* Copyright 2008-2009  Martin Sandsmark <martin.sandsmark@kde.org>
+* SPDX-FileCopyrightText: 2003-2004 Max Howell <max.howell@methylblue.com>
+* SPDX-FileCopyrightText: 2008-2009 Martin Sandsmark <martin.sandsmark@kde.org>
 *
-* This program is free software; you can redistribute it and/or
-* modify it under the terms of the GNU General Public License as
-* published by the Free Software Foundation; either version 2 of
-* the License or (at your option) version 3 or any later version
-* accepted by the membership of KDE e.V. (or its successor approved
-* by the membership of KDE e.V.), which shall act as a proxy
-* defined in Section 14 of version 3 of the license.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
+* SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 ***********************************************************************/
 
 #include "fileTree.h"
@@ -164,10 +150,10 @@ void RadialMap::Widget::mouseMoveEvent(QMouseEvent *e)
     // Same content as before
     if (m_focus == oldFocus) {
         if (tooltipRect.right() > screenRect.right()) {
-            tooltipPosition.setX(screenRect.width() - m_tooltip.width());
+            tooltipPosition.setX(screenRect.x() + screenRect.width() - m_tooltip.width());
         }
         if (tooltipRect.bottom() > screenRect.bottom()) {
-            tooltipPosition.setY(screenRect.height() - m_tooltip.height());
+            tooltipPosition.setY(screenRect.y() + screenRect.height() - m_tooltip.height());
         }
         m_tooltip.move(tooltipPosition);
         return;
@@ -239,10 +225,10 @@ void RadialMap::Widget::mouseMoveEvent(QMouseEvent *e)
     // Make sure we're visible on screen
     tooltipRect.setSize(QSize(tooltipWidth, tooltipHeight));
     if (tooltipRect.right() > screenRect.right()) {
-        tooltipPosition.setX(screenRect.width() - m_tooltip.width());
+        tooltipPosition.setX(screenRect.x() + screenRect.width() - m_tooltip.width());
     }
     if (tooltipRect.bottom() > screenRect.bottom()) {
-        tooltipPosition.setY(screenRect.height() - m_tooltip.height());
+        tooltipPosition.setY(screenRect.y() + screenRect.height() - m_tooltip.height());
     }
     m_tooltip.move(tooltipPosition);
 
